@@ -25,6 +25,9 @@ from ..exceptions import PapermillException
         (-54321, '-54321'),
         (1.2345, '1.2345'),
         (-5432.1, '-5432.1'),
+        (float('nan'), "float('nan')"),
+        (float('-inf'), "float('-inf')"),
+        (float('inf'), "float('inf')"),
         (True, 'True'),
         (False, 'False'),
         (None, 'None'),
